@@ -5,6 +5,7 @@ import xarray as xr
 from functools import partial
 from pywapor.enhancers import lulc
 import numpy as np
+import copy
 
 def default_vars(product_name, req_vars):
     """Given a `product_name` and a list of requested variables, returns a dictionary
@@ -129,20 +130,16 @@ def download(folder, latlim, lonlim, product_name, req_vars = ["lulc"],
 
     folder = os.path.join(folder, "GLOBCOVER")
 
-    appending = False
     fn = os.path.join(folder, f"{product_name}.nc")
+    req_vars_orig = copy.deepcopy(req_vars)
     if os.path.isfile(fn):
-        os.rename(fn, fn.replace(".nc", "_to_be_appended.nc"))
-        existing_ds = open_ds(fn.replace(".nc", "_to_be_appended.nc"))
-        if np.all([x in existing_ds.data_vars for x in req_vars]):
+        existing_ds = open_ds(fn)
+        req_vars_new = list(set(req_vars).difference(set(existing_ds.data_vars)))
+        if len(req_vars_new) > 0:
+            req_vars = req_vars_new
             existing_ds = existing_ds.close()
-            os.rename(fn.replace(".nc", "_to_be_appended.nc"), fn)
-            existing_ds = open_ds(fn)
-            return existing_ds[req_vars]
         else:
-            appending = True
-            fn = os.path.join(folder, f"{product_name}_appendix.nc")
-            req_vars = [x for x in req_vars if x not in existing_ds.data_vars]
+            return existing_ds[req_vars_orig]
 
     coords = {"x": ("lon", lonlim), "y": ("lat", latlim)}
 
@@ -155,19 +152,10 @@ def download(folder, latlim, lonlim, product_name, req_vars = ["lulc"],
         default_processors = default_post_processors(product_name, req_vars)
         post_processors = {k: {True: default_processors[k], False: v}[v == "default"] for k,v in post_processors.items() if k in req_vars}
 
-    ds_new = cog.download(fn, product_name, coords, variables, 
+    ds = cog.download(fn, product_name, coords, variables, 
                         post_processors, url_func, ndv = 0)
 
-    if appending:
-        ds = xr.merge([ds_new, existing_ds])
-        lbl = f"Appending new variables (`{'`, `'.join(req_vars)}`) to existing file."
-        ds = save_ds(ds, os.path.join(folder, f"{product_name}.nc"), encoding = "initiate", label = lbl)
-        remove_ds(ds_new)
-        remove_ds(existing_ds)
-    else:
-        ds = ds_new
-
-    return ds
+    return ds[req_vars_orig]
 
 if __name__ == "__main__":
 
